==> v0.1.0.tar.gz: luticate2-api/Luticate2.Utils/Middlewares/LuExceptionMiddleware.cs <==
﻿using System;
using System.Threading.Tasks;
using Luticate2.Utils.Controllers;
using Luticate2.Utils.Dbo.Basic;
using Microsoft.AspNetCore.Http;
using Newtonsoft.Json;

namespace Luticate2.Utils.Middlewares
{
    public class LuExceptionMiddleware
    {
        private readonly RequestDelegate _next;

        public LuExceptionMiddleware(RequestDelegate next)
        {
            _next = next;
        }

        public async Task Invoke(HttpContext context)
        {
            try
            {
                await _next.Invoke(context);
            }
            catch (LuResultException e)
            {
                var response = context.Response;
                response.ContentType = "application/json";
                response.StatusCode = e.Result.GetHttpCode();
                await response.WriteAsync(JsonConvert.SerializeObject(new LuApiWrapperDbo<object>
                {
                    code = e.Result.GetHttpCode(),
                    data = null,
                    message = e.Result.PublicDetails ?? e.Result.GetHttpString(),
                    Version = LuUtilsExtensions.Options.Version
                })).ConfigureAwait(false);
            }
            catch (Exception e)//TODO
            {
                var response = context.Response;
                response.ContentType = "application/json";
                response.StatusCode = 500;
                await response.WriteAsync(JsonConvert.SerializeObject(new LuApiWrapperDbo<object>
                {
                    code = 500,
                    data = null,
                    message = "Internal Error",
                    Version = LuUtilsExtensions.Options.Version
                })).ConfigureAwait(false);
            }
        }
    }
}

==> v0.1.5.tar.gz: luticate2-api/Luticate2.Utils/Middlewares/LuExceptionMiddleware.cs <==
﻿using System;
using System.Threading.Tasks;
using Luticate2.Utils.Controllers;
using Luticate2.Utils.Dbo.Basic;
using Microsoft.AspNetCore.Http;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;

namespace Luticate2.Utils.Middlewares
{
    public class LuExceptionMiddleware
    {
        private readonly RequestDelegate _next;
        private readonly ILogger<LuExceptionMiddleware> _logger;

        public LuExceptionMiddleware(RequestDelegate next, ILogger<LuExceptionMiddleware> logger)
        {
            _next = next;
            _logger = logger;
        }

        public async Task Invoke(HttpContext context)
        {
            try
            {
                await _next.Invoke(context);
            }
            catch (LuResultException e)
            {
                _logger.LogError(e.Result.PrivateDetails + "\n" + e.Result.PublicDetails + "\n" + e.StackTrace);
                var response = context.Response;
                response.ContentType = "application/json";
                response.StatusCode = e.Result.GetHttpCode();
                await response.WriteAsync(JsonConvert.SerializeObject(new LuApiWrapperDbo<object>
                {
                    code = e.Result.GetHttpCode(),
                    data = null,
                    message = e.Result.PublicDetails ?? e.Result.GetHttpString(),
                    Version = LuUtilsExtensions.Options.Version
                })).ConfigureAwait(false);
            }
            catch (Exception e)
            {
                _logger.LogError(e.ToString());
                var response = context.Response;
                response.ContentType = "application/json";
                response.StatusCode = 500;
                await response.WriteAsync(JsonConvert.SerializeObject(new LuApiWrapperDbo<object>
                {
                    code = 500,
                    data = null,
                    message = "Internal Error",
                    Version = LuUtilsExtensions.Options.Version
                })).ConfigureAwait(false);
            }
        }
    }
}
